@@ -1,6 +1,6 @@
 import aiohttp
 
-from Core import UnableToAccessApi
+from Core import *
 
 
 async def text_to_handwriting(
