@@ -7,7 +7,7 @@ from urllib.parse import quote
 import asyncio
 import pyautogui as pg
 import asyncio
-from Core import log, core, exceptions
+from Core import *
 
 pg.FAILSAFE = False
 
